@@ -397,12 +397,16 @@ class ProjectTopping(QObject):
 
                 if maptheme_record.hasExpandedStateInfo():
                     for expanded_groupnode in maptheme_record.expandedGroupNodes():
-                        maptheme_item[expanded_groupnode] = {}
+                        if expanded_groupnode not in maptheme_item:
+                            maptheme_item[expanded_groupnode] = {}
+                            maptheme_item[expanded_groupnode]["group"] = True
                         maptheme_item[expanded_groupnode]["expanded"] = True
                 # setHasCheckedStateInfo(True) is not available in the API, what makes it impossible to control the checked state of a group
                 # see https://github.com/SebastienPeillet/QGIS/commit/736e46daa640b8a9c66107b4f05319d6d2534ac5#discussion_r1037225879
                 for checked_groupnode in maptheme_record.checkedGroupNodes():
-                    maptheme_item[checked_groupnode] = {}
+                    if checked_groupnode not in maptheme_item:
+                        maptheme_item[checked_groupnode] = {}
+                        maptheme_item[checked_groupnode]["group"] = True
                     maptheme_item[checked_groupnode]["checked"] = True
 
                 self[name] = maptheme_item
@@ -422,8 +426,7 @@ class ProjectTopping(QObject):
                 variable_value = QgsExpressionContextUtils.projectScope(
                     project
                 ).variable(variable_key)
-                if variable_value:
-                    self[variable_key] = variable_value
+                self[variable_key] = variable_value or None
 
     class Layouts(dict):
         """
@@ -587,9 +590,18 @@ class ProjectTopping(QObject):
         And it generates and stores the toppingfiles according th the Target.
         """
         projecttopping_dict = {}
-        projecttopping_dict["layertree"] = self.layertree.items_list(target)
-        projecttopping_dict["mapthemes"] = dict(self.mapthemes)
-        projecttopping_dict["variables"] = dict(self.variables)
-        projecttopping_dict["layouts"] = self.layouts.item_dict(target)
-        projecttopping_dict["layerorder"] = self.layerorder
+        layertree_items_list = self.layertree.items_list(target)
+        if layertree_items_list:
+            projecttopping_dict["layertree"] = layertree_items_list
+        mapthemes_dict = dict(self.mapthemes)
+        if mapthemes_dict:
+            projecttopping_dict["mapthemes"] = mapthemes_dict
+        variables_dict = dict(self.variables)
+        if variables_dict:
+            projecttopping_dict["variables"] = variables_dict
+        layouts_item_dict = self.layouts.item_dict(target)
+        if layouts_item_dict:
+            projecttopping_dict["layouts"] = layouts_item_dict
+        if self.layerorder:
+            projecttopping_dict["layerorder"] = self.layerorder
         return projecttopping_dict
